==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/CodePipeline/StartPipelineExecution.pm <==

package Paws::CodePipeline::StartPipelineExecution;
  use Moose;
  has name => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StartPipelineExecution');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodePipeline::StartPipelineExecutionOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::StartPipelineExecution - Arguments for method StartPipelineExecution on Paws::CodePipeline

=head1 DESCRIPTION

This class represents the parameters used for calling the method StartPipelineExecution on the 
AWS CodePipeline service. Use the attributes of this class
as arguments to method StartPipelineExecution.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to StartPipelineExecution.

As an example:

  $service_obj->StartPipelineExecution(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> name => Str

  

The name of the pipeline to start.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StartPipelineExecution in L<Paws::CodePipeline>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/CodePipeline/StartPipelineExecution.pm <==

package Paws::CodePipeline::StartPipelineExecution;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'name' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'StartPipelineExecution');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodePipeline::StartPipelineExecutionOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodePipeline::StartPipelineExecution - Arguments for method StartPipelineExecution on Paws::CodePipeline

=head1 DESCRIPTION

This class represents the parameters used for calling the method StartPipelineExecution on the 
AWS CodePipeline service. Use the attributes of this class
as arguments to method StartPipelineExecution.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to StartPipelineExecution.

As an example:

  $service_obj->StartPipelineExecution(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> Name => Str

  The name of the pipeline to start.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method StartPipelineExecution in L<Paws::CodePipeline>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
